==> ui-react-1.0.84.tgz: package/esm/Property/Property.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
const _excluded = ["version", "size", "name", "value", "separator", "responsive", "mediaQuery", "ItemProps", "NameProps", "NameWrapperProps", "ValueProps", "className", "children"];
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
import React from 'react';
import { is } from '@onesy/utils';
import { classNames, style as styleMethod, useOnesyTheme } from '@onesy/style-react';
import LineElement from '../Line/Line';
import TypeElement from '../Type';
import useMediaQuery from '../useMediaQuery';
import { staticClassName } from '../utils';
const useStyle = styleMethod(theme => ({
  root: {},
  'version_row-50': {
    '& > *': {
      flex: '1 1 50%'
    }
  },
  'version_row-20': {
    '& > *:first-child': {
      flex: '1 1 20%'
    },
    '& > *:last-child': {
      flex: '1 1 80%'
    }
  },
  text: {
    wordBreak: 'break-word'
  }
}), {
  name: 'onesy-Property'
});
const Property = /*#__PURE__*/React.forwardRef((props_, ref) => {
  const theme = useOnesyTheme();
  const props = React.useMemo(() => _objectSpread(_objectSpread(_objectSpread({}, theme?.ui?.elements?.all?.props?.default), theme?.ui?.elements?.onesyProperty?.props?.default), props_), [props_]);
  const Line = React.useMemo(() => theme?.elements?.Line || LineElement, [theme]);
  const Type = React.useMemo(() => theme?.elements?.Type || TypeElement, [theme]);
  const {
      version: version_ = 'row-20',
      size = 'regular',
      name,
      value: value_,
      separator,
      responsive = true,
      mediaQuery = `(max-width: 768px)`,
      ItemProps,
      NameProps,
      NameWrapperProps,
      ValueProps,
      className,
      children
    } = props,
    other = _objectWithoutProperties(props, _excluded);
  const {
    classes
  } = useStyle();
  const refs = {
    root: React.useRef(undefined)
  };
  const mobile = useMediaQuery(mediaQuery, {
    element: refs.root.current
  });
  let version = version_;
  if (responsive && mobile) {
    version = 'column';
  }
  const value = value_ !== undefined ? value_ : children;
  const propsRoot = {};
  if (version === 'column') {
    propsRoot.gap = 0.5;
    propsRoot.direction = 'column';
    propsRoot.align = 'flex-start';
  }
  if (version.includes('row')) {
    propsRoot.gap = 2;
    propsRoot.direction = 'row';
    propsRoot.align = 'flex-start';
  }
  if (version === 'row') {
    propsRoot.justify = 'flex-start';
  } else if (['row-20', 'row-50', 'row-between'].includes(version)) {
    propsRoot.justify = 'space-between';
  }
  return /*#__PURE__*/React.createElement(Line, _extends({
    ref: item => {
      if (ref) {
        if (is('function', ref)) ref(item);else ref.current = item;
      }
      refs.root.current = item;
    },
    fullWidth: true,
    className: classNames([staticClassName('Property', theme) && ['onesy-Property-root', `onesy-Property-version-${version}`, `onesy-Property-size-${size}`], className, classes.root, classes[`version_${version}`]])
  }, propsRoot, other), /*#__PURE__*/React.createElement(Line, _extends({
    gap: 0,
    direction: "row"
  }, NameWrapperProps), is('simple', name) ? /*#__PURE__*/React.createElement(Type, _extends({
    version: size === 'large' ? 'l1' : size === 'regular' ? 'l2' : 'l3'
  }, ItemProps, NameProps, {
    className: classNames([staticClassName('Property', theme) && ['onesy-Property-name'], ItemProps?.className, NameProps?.className, classes.text, classes.name])
  }), name) : name, separator), is('simple', value) ? /*#__PURE__*/React.createElement(Type, _extends({
    version: size === 'large' ? 'b1' : size === 'regular' ? 'b2' : 'b3'
  }, ItemProps, ValueProps, {
    className: classNames([staticClassName('Property', theme) && ['onesy-Property-name'], ItemProps?.className, ValueProps?.className, classes.text, classes.name])
  }), value) : value);
});
Property.displayName = 'onesy-Property';
export default Property;

==> ui-react-1.1.440.tgz: package/esm/Property/Property.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
const _excluded = ["version", "size", "name", "value", "separator", "responsive", "mediaQuery", "ItemProps", "NameProps", "NameWrapperProps", "ValueProps", "className", "children"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
import React from 'react';
import { is } from '@amaui/utils';
import { classNames, style as styleMethod, useAmauiTheme } from '@amaui/style-react';
import LineElement from '../Line/Line';
import TypeElement from '../Type';
import useMediaQuery from '../useMediaQuery';
import { staticClassName } from '../utils';
const useStyle = styleMethod(theme => ({
  root: {},
  'version_row-50': {
    '& > *': {
      flex: '1 1 50%'
    }
  },
  'version_row-20': {
    '& > *:first-child': {
      flex: '1 1 20%'
    },
    '& > *:last-child': {
      flex: '1 1 80%'
    }
  },
  text: {
    wordBreak: 'break-word'
  }
}), {
  name: 'amaui-Property'
});
const Property = /*#__PURE__*/React.forwardRef((props_, ref) => {
  const theme = useAmauiTheme();
  const props = React.useMemo(() => _objectSpread(_objectSpread(_objectSpread({}, theme?.ui?.elements?.all?.props?.default), theme?.ui?.elements?.amauiProperty?.props?.default), props_), [props_]);
  const Line = React.useMemo(() => theme?.elements?.Line || LineElement, [theme]);
  const Type = React.useMemo(() => theme?.elements?.Type || TypeElement, [theme]);
  const {
      version: version_ = 'row-20',
      size = 'regular',
      name,
      value: value_,
      separator,
      responsive = true,
      mediaQuery = `(max-width: 768px)`,
      ItemProps,
      NameProps,
      NameWrapperProps,
      ValueProps,
      className,
      children
    } = props,
    other = _objectWithoutProperties(props, _excluded);
  const {
    classes
  } = useStyle();
  const refs = {
    root: React.useRef()
  };
  const mobile = useMediaQuery(mediaQuery, {
    element: refs.root.current
  });
  let version = version_;
  if (responsive && mobile) {
    version = 'column';
  }
  const value = value_ !== undefined ? value_ : children;
  const propsRoot = {};
  if (version === 'column') {
    propsRoot.gap = 0.5;
    propsRoot.direction = 'column';
    propsRoot.align = 'flex-start';
  }
  if (version.includes('row')) {
    propsRoot.gap = 2;
    propsRoot.direction = 'row';
    propsRoot.align = 'flex-start';
  }
  if (version === 'row') {
    propsRoot.justify = 'flex-start';
  } else if (['row-20', 'row-50', 'row-between'].includes(version)) {
    propsRoot.justify = 'space-between';
  }
  return /*#__PURE__*/React.createElement(Line, _extends({
    ref: item => {
      if (ref) {
        if (is('function', ref)) ref(item);else ref.current = item;
      }
      refs.root.current = item;
    },
    fullWidth: true,
    className: classNames([staticClassName('Property', theme) && ['amaui-Property-root'], className, classes.root, classes[`version_${version}`]])
  }, propsRoot, other), /*#__PURE__*/React.createElement(Line, _extends({
    gap: 0,
    direction: "row"
  }, NameWrapperProps), is('simple', name) ? /*#__PURE__*/React.createElement(Type, _extends({
    version: size === 'large' ? 'l1' : size === 'regular' ? 'l2' : 'l3'
  }, ItemProps, NameProps, {
    className: classNames([staticClassName('Property', theme) && ['amaui-Property-name'], ItemProps?.className, NameProps?.className, classes.text, classes.name])
  }), name) : name, separator), is('simple', value) ? /*#__PURE__*/React.createElement(Type, _extends({
    version: size === 'large' ? 'b1' : size === 'regular' ? 'b2' : 'b3'
  }, ItemProps, ValueProps, {
    className: classNames([staticClassName('Property', theme) && ['amaui-Property-name'], ItemProps?.className, ValueProps?.className, classes.text, classes.name])
  }), value) : value);
});
Property.displayName = 'amaui-Property';
export default Property;
